@@ -1,7 +1,7 @@
 package Perinci::Access::Simple::Client;
 
-our $DATE = '2014-10-24'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2015-03-05'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 use 5.010001;
 use strict;
@@ -255,13 +255,7 @@ sub _parse_or_request {
         $e = $@;
         return [400, "Can't encode request as JSON: $e"] if $e;
 
-        if (length($req_json) > 1000) {
-            $out->write("J" . length($req_json) . "\015\012");
-            $out->write($req_json);
-            $out->write("\015\012");
-        } else {
-            $out->write("j$req_json\015\012");
-        }
+        $out->write("j$req_json\015\012");
         $log->tracef("Sent request to server: %s", $req_json);
 
         # XXX alarm/timeout
@@ -270,16 +264,11 @@ sub _parse_or_request {
         if (!$line) {
             $self->_delete_cache($cache_key);
             return [500, "Empty response from server"];
-        } elsif ($line !~ /^J(\d+)/) {
+        } elsif ($line !~ /^j(.+)/) {
             $self->_delete_cache($cache_key);
             return [500, "Invalid response line from server: $line"];
         }
-        my $res_json;
-        $log->tracef("Reading $1 bytes from server ...");
-        $in->read($res_json, $1);
-        $log->tracef("Got from server: %s", $res_json);
-        $in->getline; # CRLF after response
-        eval { $res = $json->decode($res_json) };
+        eval { $res = $json->decode($1) };
         $e = $@;
         if ($e) {
             $self->_delete_cache($cache_key);
@@ -353,7 +342,7 @@ Perinci::Access::Simple::Client - Riap::Simple client
 
 =head1 VERSION
 
-This document describes version 0.18 of Perinci::Access::Simple::Client (from Perl distribution Perinci-Access-Simple-Client), released on 2014-10-24.
+This document describes version 0.19 of Perinci::Access::Simple::Client (from Perl distribution Perinci-Access-Simple-Client), released on 2015-03-05.
 
 =head1 SYNOPSIS
 
@@ -415,8 +404,6 @@ server: either via TCP (where the server can be on a remote computer), Unix
 socket, or a program (where the program can also be on a remote computer, e.g.
 accessed via ssh).
 
-This class uses L<Log::Any> for logging.
-
 =head1 METHODS
 
 =head2 PKG->new(%attrs) => OBJ
@@ -503,7 +490,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
